class DoNotUpdate:
    """
    Helper to determine between provided and not provided 'None' parameters in request bodies.

    Usefull in such cases, where it has to be differentiated between a provided 'None' and a not provided parameter, when it is also by default 'None'.

    Examples
    ========

    >>> body = { 'param': None }
    >>> param = body.get('param', DoNotUpdate())
    >>> param
    None

    >>> body = {}
    >>> param = body.get('param', DoNotUpdate())
    >>> param
    <__main__.DoNotUpdate object at 0x7f321d0052e0>
    """
    pass



from typing import Optional, List

from aws_cdk.aws_lambda import LayerVersion, Runtime, Code
from aws_cdk.core import Stack

from b_lambda_layer_common.source import root


class Layer(LayerVersion):
    def __init__(self, scope: Stack, name: str):
        self.__scope = scope

        super().__init__(
            scope=scope,
            id=name,
            code=Code.from_asset(root),
            compatible_runtimes=self.runtimes(),
            layer_version_name=name,
        )

    def runtimes(self) -> Optional[List[Runtime]]:
        return [
            Runtime.PYTHON_3_6,
            Runtime.PYTHON_3_7,
            Runtime.PYTHON_3_8
        ]
